summaryrefslogtreecommitdiff
path: root/chart2
diff options
context:
space:
mode:
authorAndrea Gelmini <andrea.gelmini@gelma.net>2019-01-31 17:44:50 +0000
committerJulien Nabet <serval2412@yahoo.fr>2019-02-02 07:33:45 +0100
commit6a815d1b051b0e38611ba4a864ecff3055f81dc5 (patch)
tree613e9b3f860e7f5c9792a0509f44dad333394f9d /chart2
parent29db6427ea6e3f24fbacfd6ac053231106518749 (diff)
Fix typo
Change-Id: I19361359910a3b30c12a4bef28308e082b4ff66f Reviewed-on: https://gerrit.libreoffice.org/67273 Tested-by: Jenkins Reviewed-by: Julien Nabet <serval2412@yahoo.fr>
Diffstat (limited to 'chart2')
-rw-r--r--chart2/source/inc/OPropertySet.hxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/chart2/source/inc/OPropertySet.hxx b/chart2/source/inc/OPropertySet.hxx
index e5f18492a96b..2ee1caa164c8 100644
--- a/chart2/source/inc/OPropertySet.hxx
+++ b/chart2/source/inc/OPropertySet.hxx
@@ -106,7 +106,7 @@ protected:
sal_Int32 nHandle,
const css::uno::Any& rValue ) override;
/** The same as setFastProperyValue; nHandle is always valid.
The changes must not be broadcasted in this method.
@attention
@@ -128,7 +128,7 @@ protected:
const css::uno::Any& rValue ) override;
/**
- The same as getFastProperyValue, but return the value through rValue and
+ The same as getFastPropertyValue, but return the value through rValue and
nHandle is always valid.
@see ::cppu::OPropertySetHelper
@@ -106,7 +106,7 @@ protected:
sal_Int32 nHandle,
const css::uno::Any& rValue ) override;
- /** The same as setFastProperyValue; nHandle is always valid.
+ /** The same as setFastPropertyValue; nHandle is always valid.
The changes must not be broadcasted in this method.